# Planned work

- [ ] Support for better prompts (select, multi-select, etc.)
- [ ] Strict Pyright -- Can this repo be entirely in strict mode?
- [ ] Other simple UI components (e.g.: simple file tree)
- [ ] Testing tools -- Can we provide users with a good easy framework to test their CLI?
- [ ] Themes support -- How can users extend Formatter and/or select a theme?
